@@ -80,20 +80,6 @@ QString Email::toString() const
     return str;
 }
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-void Email::setParameters(const QMap<QString, QStringList> &params)
-{
-    d->mParamMap = ParameterMap::fromQMap(params);
-}
-#endif
-
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-QMap<QString, QStringList> Email::parameters() const
-{
-    return d->mParamMap.toQMap();
-}
-#endif
-
 void Email::setParams(const ParameterMap &params)
 {
     d->mParamMap = params;
